Generics defined at the GCIMS package. We are open to moving them to an existing generics-only package if you need so.

dtime(object, ...)

getChromatogram(object, ...)

getSpectrum(object, ...)

getTIS(object, ...)

getRIC(object, ...)

plotTIS(object, ...)

plotRIC(object, ...)

filterDt(object, ...)

decimate(object, ...)

align(object, ...)

prealign(object, ...)

estimateBaseline(object, ...)

baseline(object, ...)

baseline(object) <- value

integratePeaks(object, ...)

Arguments

object

An object to get the baseline

...

Additional arguments for downstream methods

value

baseline to set

Value

A numeric vector with the drift time

A GCIMSChromatogram (one sample) or a GCIMSChromatogramSet (several samples, one chromatogram each, with a copy of pData())

A GCIMSSpectrum (one sample) or a GCIMSSpectrumSet (several samples, one spectrum each, with a copy of pData())

The Total Ion Spectrum as a numeric vector or a matrix (depending if the object is one sample or several)

The Reverse Ion Chromatogram, as a numeric vector or a matrix (depending if the object is one sample or several)

A plot

A plot

The object, modified

The object, modified

The object, modified

The object, modified

The object, with a baseline estimated

The baseline of the object

The object

The object, with integrated peaks

Functions

  • dtime(): Get drift time vector

  • getChromatogram(): Get a chromatogram

  • getSpectrum(): Get a spectrum

  • getTIS(): Get the Total Ion Spectrum

  • getRIC(): Get the Reverse Ion Chromatogram

  • plotTIS(): Plot total ion spectrum

  • plotRIC(): Plot Reverse Ion Chromatogram

  • filterDt(): Filter in Drift time

  • decimate(): Decimate an object

  • align(): Align an object

  • prealign(): Align an object in drift time

  • estimateBaseline(): Estimate the baseline in an object

  • baseline(): Get the baseline of an object

  • baseline(object) <- value: Set the baseline of an object

  • integratePeaks(): Integrate peaks of an object

Examples

x <- GCIMSSample(
  drift_time = 1:2,
  retention_time = 1:3,
  data = matrix(1:6, nrow = 2, ncol = 3)
)
dtime(x) # c(1,2)
#> [1] 1 2