Plot Reverse Ion Chromatograms

# S4 method for class 'GCIMSDataset'
plotRIC(object, rt_range = NULL, sample = NULL, color_by = "SampleID")

Arguments

object

A GCIMSDataset object

rt_range

The minimum and maximum retention times to extract (length 2 vector)

sample

A number or a string with the sample index or name. If NULL, all samples are returned

color_by

The name of a pData(object) column (or "SampleID") used to color the chromatograms

Value

A plot