Plot Total Ion Spectra

# S4 method for class 'GCIMSDataset'
plotTIS(object, dt_range = NULL, sample = NULL, color_by = "SampleID")

Arguments

object

A GCIMSDataset object

dt_range

The minimum and maximum drift times to extract (length 2 vector)

sample

A number or a string with the sample index or name. If NULL, all samples are returned

color_by

The name of a pData(object) column (or "SampleID") used to color the spectra

Value

The plot of the TIS