getChromatogram-GCIMSDataset-method.RdGet a chromatogram from each sample of a dataset
# S4 method for class 'GCIMSDataset'
getChromatogram(
object,
dt_range = NULL,
rt_range = NULL,
dt_idx = NULL,
rt_idx = NULL,
aggregate = colSums
)A GCIMSDataset object
The minimum and maximum drift times to extract (length 2 vector)
The minimum and maximum retention times to extract (length 2 vector)
A numeric vector with the drift time indices to extract (or a logical vector of the length of drift time)
A numeric vector with the retention time indices to extract (or a logical vector of the length of retention time)
Function that takes the subsetted intensity matrix of each
sample according to the region of interest and aggregates the drift times,
returning a vector representing the chromatogram intensity. colSums by
default.
A GCIMSChromatogramSet, with one GCIMSChromatogram per sample
(each on its own retention time axis, no interpolation across samples) and
a copy of pData(object)