plotRIC-GCIMSDataset-method.RdPlot Reverse Ion Chromatograms
# S4 method for class 'GCIMSDataset'
plotRIC(object, rt_range = NULL, sample = NULL, color_by = "SampleID")A GCIMSDataset object
The minimum and maximum retention times to extract (length 2 vector)
A number or a string with the sample index or name. If NULL, all samples are returned
The name of a pData(object) column (or "SampleID") used to color the chromatograms
A plot