plotTIS-GCIMSDataset-method.RdPlot Total Ion Spectra
# S4 method for class 'GCIMSDataset'
plotTIS(object, dt_range = NULL, sample = NULL, color_by = "SampleID")A GCIMSDataset object
The minimum and maximum drift times to extract (length 2 vector)
A number or a string with the sample index or name. If NULL, all samples are returned
The name of a pData(object) column (or "SampleID") used to color the spectra
The plot of the TIS